@@ -345,35 +345,34 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
 
             if team == good_team:
 
-                legend = ax.legend(loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
+                legend_elements = [Line2D([0], [0], color = colors_dict['SHOT'], marker = 'o',
+                                    markerfacecolor = colors_dict['GOAL'], label = 'GOAL', markersize = 45),
+                                    
+                                    Line2D([0], [0], marker='o', color = colors_dict['SHOT'], label= 'SHOT',
+                                        markerfacecolor = colors_dict['SHOT'], markersize = 45),
+
+                                   Line2D([0], [0], marker='o', color = colors_dict['MISS'], label= 'MISS',
+                                    markerfacecolor = colors_dict['MISS'], markersize = 45)]
+
+                legend = ax.legend(handles = legend_elements, loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
                                     title_fontsize = 16, facecolor = 'white', framealpha = 1,
                                     edgecolor = 'gray').set_zorder(-1)
-
-
-                #for handle in legend.legendHandles:
-
-                #    handle._sizes = [250]
-
-                        #handle._legmarker.set_markersize(250)
-
-
-                ax.legend(handler_map={type(): HandlerPathCollection(update_func=update_prop)})
   
             if team == bad_team:
 
-                legend = ax.legend(loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
+                legend_elements = [Line2D([0], [0], color = colors_dict['SHOT'], marker = 'o',
+                                    markerfacecolor = colors_dict['GOAL'], label = 'GOAL', markersize = 45),
+                                    
+                                    Line2D([0], [0], marker='o', color = colors_dict['SHOT'], label= 'SHOT',
+                                        markerfacecolor = colors_dict['SHOT'], markersize = 45),
+
+                                   Line2D([0], [0], marker='o', color = colors_dict['MISS'], label= 'MISS',
+                                    markerfacecolor = colors_dict['MISS'], markersize = 45)]
+
+                legend = ax.legend(handles = legend_elements, loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
                                     title_fontsize = 16, facecolor = 'white', framealpha = 1,
                                     edgecolor = 'gray').set_zorder(-1)
                 
-                #for handle in legend.legendHandles:
-
-                #    handle._sizes = [250]
-
-                    #for handle in legend.legendHandles:
-                        
-                    #    handle._legmarker.set_markersize(250)
-
-                ax.legend(handler_map={type(): HandlerPathCollection(update_func=update_prop)})
 
         if save_img == True:
             
